@@ -1,6 +1,6 @@
 """Módulo de iteração de listas
 """
-def print_lol(the_list, level):
+def print_lol(the_list, level=0):
     """Função que recebe uma lista e itera. A lista pode conter vários níveis de profundiade
     """
         
